:mod:`nilearn.mass_univariate`: Mass-Univariate Analysis
========================================================

.. automodule:: nilearn.mass_univariate
   :no-members:
   :no-inherited-members:

.. No relevant user manual section yet.

Functions
---------

.. currentmodule:: nilearn.mass_univariate

.. autosummary::
   :toctree: generated/
   :template: function.rst

   permuted_ols
